==> jc-1.4.0.tar.gz: java__5fcup/internal__5ferror.h <==
// public class java_cup.internal_error

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class b089976210a4571 java__5fcup_internal__5ferror

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java__5fcup_internal__5ferror_H_
#define _JC_java__5fcup_internal__5ferror_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java__5fcup_internal__5ferror$sub_refs	_jc_java__5fcup_internal__5ferror$sub_refs;
typedef struct _jc_java__5fcup_internal__5ferror$sub_nonrefs	_jc_java__5fcup_internal__5ferror$sub_nonrefs;
typedef struct _jc_java__5fcup_internal__5ferror$refs	_jc_java__5fcup_internal__5ferror$refs;
typedef struct _jc_java__5fcup_internal__5ferror$nonrefs	_jc_java__5fcup_internal__5ferror$nonrefs;
typedef struct _jc_java__5fcup_internal__5ferror$object	_jc_java__5fcup_internal__5ferror$object;

typedef const struct _jc_java__5fcup_internal__5ferror$vmethods	_jc_java__5fcup_internal__5ferror$vmethods;
typedef const struct _jc_java__5fcup_internal__5ferror$vtable	_jc_java__5fcup_internal__5ferror$vtable;
typedef const struct _jc_java__5fcup_internal__5ferror$vtype	_jc_java__5fcup_internal__5ferror$vtype;

// Constructors
extern void _jc_java__5fcup_internal__5ferror$method$_init$c31b894660454d13(_jc_env *, struct _jc_java__5fcup_internal__5ferror$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_java__5fcup_internal__5ferror$method$crash$351f6538b507e845(_jc_env *, struct _jc_java__5fcup_internal__5ferror$object *);

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_internal__5ferror$method_info$crash$351f6538b507e845;

// Virtual methods structure
struct _jc_java__5fcup_internal__5ferror$vmethods {
	void	(*crash$351f6538b507e845)(_jc_env *, struct _jc_java__5fcup_internal__5ferror$object *);
};

// Vtable
struct _jc_java__5fcup_internal__5ferror$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java__5fcup_internal__5ferror$vmethods	java__5fcup_internal__5ferror;
};

// Vtype
struct _jc_java__5fcup_internal__5ferror$vtype {
	_jc_type			type;
	_jc_java__5fcup_internal__5ferror$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_internal__5ferror$sub_refs {
};

// Reference instance fields (object)
struct _jc_java__5fcup_internal__5ferror$refs {
    _jc_java__5fcup_internal__5ferror$sub_refs	java__5fcup_internal__5ferror;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_internal__5ferror$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_internal__5ferror$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java__5fcup_internal__5ferror$sub_nonrefs	java__5fcup_internal__5ferror;
};

// Object instance structure
struct _jc_java__5fcup_internal__5ferror$object {
	_jc_java__5fcup_internal__5ferror$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_internal__5ferror$vtype	*vtype;
	_jc_java__5fcup_internal__5ferror$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_internal__5ferror$vtype _jc_java__5fcup_internal__5ferror$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_internal__5ferror, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_internal__5ferror$class_object;

#endif	/* _JC_java__5fcup_internal__5ferror_H_ */

==> jc-1.4.6.tar.gz: java__5fcup/internal__5ferror.h <==
// public class java_cup.internal_error

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class b089976210a4571 java__5fcup_internal__5ferror

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java__5fcup_internal__5ferror_H_
#define _JC_java__5fcup_internal__5ferror_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java__5fcup_internal__5ferror$sub_refs	_jc_java__5fcup_internal__5ferror$sub_refs;
typedef struct _jc_java__5fcup_internal__5ferror$sub_nonrefs	_jc_java__5fcup_internal__5ferror$sub_nonrefs;
typedef struct _jc_java__5fcup_internal__5ferror$refs	_jc_java__5fcup_internal__5ferror$refs;
typedef struct _jc_java__5fcup_internal__5ferror$nonrefs	_jc_java__5fcup_internal__5ferror$nonrefs;
typedef struct _jc_java__5fcup_internal__5ferror$object	_jc_java__5fcup_internal__5ferror$object;

typedef const struct _jc_java__5fcup_internal__5ferror$vmethods	_jc_java__5fcup_internal__5ferror$vmethods;
typedef const struct _jc_java__5fcup_internal__5ferror$vtable	_jc_java__5fcup_internal__5ferror$vtable;
typedef const struct _jc_java__5fcup_internal__5ferror$vtype	_jc_java__5fcup_internal__5ferror$vtype;

// Constructors
extern void _jc_java__5fcup_internal__5ferror$method$_init$c31b894660454d13(_jc_env *, struct _jc_java__5fcup_internal__5ferror$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java__5fcup_internal__5ferror$method$crash$351f6538b507e845(_jc_env *, struct _jc_java__5fcup_internal__5ferror$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java__5fcup_internal__5ferror$method_info$crash$351f6538b507e845;

// Virtual methods structure
struct _jc_java__5fcup_internal__5ferror$vmethods {
	void	(*crash$351f6538b507e845)(_jc_env *, struct _jc_java__5fcup_internal__5ferror$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java__5fcup_internal__5ferror$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java__5fcup_internal__5ferror$vmethods	java__5fcup_internal__5ferror;
};

// Vtype
struct _jc_java__5fcup_internal__5ferror$vtype {
	_jc_type			type;
	_jc_java__5fcup_internal__5ferror$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_internal__5ferror$sub_refs {
};

// Reference instance fields (object)
struct _jc_java__5fcup_internal__5ferror$refs {
    _jc_java__5fcup_internal__5ferror$sub_refs	java__5fcup_internal__5ferror;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_internal__5ferror$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_internal__5ferror$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java__5fcup_internal__5ferror$sub_nonrefs	java__5fcup_internal__5ferror;
};

// Object instance structure
struct _jc_java__5fcup_internal__5ferror$object {
	_jc_java__5fcup_internal__5ferror$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_internal__5ferror$vtype	*vtype;
	_jc_java__5fcup_internal__5ferror$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_internal__5ferror$vtype _jc_java__5fcup_internal__5ferror$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_internal__5ferror, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_internal__5ferror$class_object;

#endif	/* _JC_java__5fcup_internal__5ferror_H_ */
